from dataclasses import dataclass

from lerobot.teleoperators.config import TeleoperatorConfig


@TeleoperatorConfig.register_subclass("lerobot_teleoperator_bimanual_leader")
@dataclass
class BiStaraiLeaderConfig(TeleoperatorConfig):
    left_arm_port: str
    right_arm_port: str



from setuptools import setup, find_packages

setup(
    name="lerobot_teleoperator_bimanual_leader",
    version="0.0.1",
    description="LeRobot bimanual_leader integration",
    author="Welt-liu",
    author_email="1994524450@qq.com",
    packages=find_packages(),
    install_requires=[
        "lerobot",
        "lerobot-motor-starai",
        "lerobot_teleoperator_violin",
        "fashionstar-uart-sdk>=1.3.6"
    ],
    python_requires=">=3.10",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
    ],
)
